@@ -55,7 +55,7 @@ class _HydraulicCrossSectionStation(_Model):
 class _HydraulicLongitudinalStation(_Model):
     roughness: float = Field(..., gt=0.0, description="Friction coefficient")
     cross_section: List[_HydraulicCrossSectionStation] = Field(
-        ..., min_items=3, description="List of points defining the channel bottom",
+        ..., min_items=3, description="List of points defining the channel bottom"
     )
 
     @validator("cross_section")
@@ -90,7 +90,7 @@ class _HydraulicRouting(_Model):
     stations: Union[
         _HydraulicLongitudinalStation, List[_HydraulicLongitudinalDelimitedStation]
     ] = Field(
-        ..., min_items=1, description="Longitudinal stations defining channel geometry",
+        ..., min_items=1, description="Longitudinal stations defining channel geometry"
     )
     roughness_model: ChannelRoughnessModel = Field(
         ChannelRoughnessModel.CHEZY, description="Friction loss approximation method"
@@ -275,7 +275,7 @@ class ValveModel(str, enum.Enum):
 class Valve(_Link):
     element_class: str = Field("Valve", const=True)
     model: ValveModel = Field(..., description="Specific type of valve")
-    coefficient: float = Field(..., ge=0.0, description="Discharge coefficient")
+    coefficient: float = Field(..., gt=0.0, description="Discharge coefficient")
     diameter: float = Field(
         ..., ge=0.0, description="Measured characteristic internal diameter"
     )
@@ -284,30 +284,41 @@ class Valve(_Link):
     )
 
 
-class WeirModel(str, enum.Enum):
+class FlowModel(str, enum.Enum):
     FREE = "free"
     SUBMERGED = "submerged"
     DYNAMIC = "dynamic"
 
 
-class Weir(_Link):
-    element_class: str = Field("Weir", const=True)
-    model: WeirModel = Field(..., description="Specific type of weir")
+class _FlowRelation(_Link):
     coefficient: float = Field(..., gt=0.0, description="Discharge coefficient")
-    min_crest_level: float
-    max_crest_level: float
+    flow_model: FlowModel = Field(..., description="Flow model")
+
+
+class Weir(_FlowRelation):
+    element_class: str = Field("Weir", const=True)
+    min_crest_level: float = Field(..., description="Minimum crest level")
+    max_crest_level: float = Field(..., description="Maximum crest level")
     crest_width: float = Field(..., gt=0.0)
 
 
-class OrificeModel(str, enum.Enum):
-    FREE = "free"
-    SUBMERGED = "submerged"
-    DYNAMIC = "dynamic"
+class _TopDownOrifice(_FlowRelation):
+    bottom_level: float = Field(..., description="Bottom level")
+    min_top_level: float = Field(..., description="Minimum top level")
+    max_top_level: float = Field(..., description="Maximum top level")
+    reference_width: float = Field(..., gt=0.0)
 
 
-class Orifice(_Link):
-    element_class: str = Field("Orifice", const=True)
-    model: OrificeModel = Field(..., description="Specific type of orifice")
-    coefficient: float = Field(..., gt=0.0, description="Discharge coefficient")
-    min_aperture: float = Field(..., ge=0.0, description="Minimum aperture")
-    max_aperture: float = Field(..., ge=0.0, description="Maximum aperture")
+class TopDownRectangularOrifice(_FlowRelation):
+    element_class: str = Field("TopDownRectangularOrifice", const=True)
+
+
+class TopDownSphericalOrifice(_FlowRelation):
+    element_class: str = Field("TopDownSphericalOrifice", const=True)
+
+
+class Drain(_FlowRelation):
+    element_class: str = Field("Drain", const=True)
+    level: float = Field(..., description="Level at which drain is installed")
+    min_area: float = Field(..., ge=0.0, description="Minimum aperture area")
+    max_area: float = Field(..., gt=0.0, description="Maximum aperture area")
